==> cloudt-system-api-0.2.9.1-20240422.034614-1-sources.jar: com/elitescloud/cloudt/system/provider/org/OrgRpcService.java <==
package com.elitescloud.cloudt.system.provider.org;

import com.elitescloud.boot.common.param.IdCodeNameParam;
import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.common.base.PagingVO;
import com.elitescloud.cloudt.system.dto.SysOrgBasicDTO;
import com.elitescloud.cloudt.system.dto.req.OrgUpsertDTO;
import com.elitescloud.cloudt.system.dto.req.SysOrgPageQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysOrgDetailRespDTO;
import com.elitescloud.cloudt.system.dto.resp.SysOrgPageRespDTO;
import com.elitescloud.cloudt.system.param.SysOrgQueryDTO;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 组织服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 2/23/2023
 */
@Validated
@Unicom(domain = InvokeDomain.SYSTEM, path = OrgRpcService.URI)
public interface OrgRpcService {
    String URI = Application.URI_PREFIX + "/org";

    /**
     * 保存组织
     * <p>
     * 如果id不为空，则是修改
     *
     * @param upsertDTO 组织信息
     * @return 组织ID
     */
    @PostMapping(value = "/upsert")
    ApiResult<Long> upsert(@RequestBody @Valid OrgUpsertDTO upsertDTO);

    /**
     * 修改启用状态
     *
     * @param id      组织ID
     * @param enabled 启用状态
     * @return 组织ID
     */
    @PatchMapping(value = "/updateEnabled")
    ApiResult<Long> updateEnabled(@NotNull(message = "组织ID为空") @RequestParam("id") Long id,
                                  @NotNull(message = "启用状态为空") @RequestParam("enabled") Boolean enabled);

    /**
     * 删除组织
     * <p>
     * 如果下面有子组织，则不可直接删除
     *
     * @param id 组织ID
     * @return 组织ID
     */
    @DeleteMapping(value = "/delete")
    ApiResult<Long> delete(@NotNull(message = "组织ID为空") @RequestParam("id") Long id);

    /**
     * 根据ID获取组织信息
     *
     * @param id 组织ID
     * @return 组织信息
     */
    @GetMapping(value = "/getById")
    ApiResult<SysOrgBasicDTO> getById(@NotNull(message = "组织ID为空") @RequestParam("id") Long id);

    /**
     * 根据ID获取组织详细信息
     *
     * @param id             组织ID
     * @param withParentType 指定类型的上级组织，{@link com.elitescloud.cloudt.system.constant.OrgType}
     * @return 组织信息
     */
    @GetMapping(value = "/getDetailById")
    ApiResult<SysOrgDetailRespDTO> getDetailById(@NotNull(message = "组织ID为空") @RequestParam("id") Long id,
                                                 @RequestParam(value = "withParentType", required = false) String withParentType);

    /**
     * 根据编码获取组织信息
     *
     * @param code 组织编码
     * @return 组织信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysOrgBasicDTO> getByCode(@NotBlank(message = "组织编码为空") @RequestParam("code") String code);

    /**
     * 根据编码获取组织详细信息
     *
     * @param code           组织编码
     * @param withParentType 指定类型的上级组织，{@link com.elitescloud.cloudt.system.constant.OrgType}
     * @return 组织信息
     */
    @GetMapping(value = "/getDetailByCode")
    ApiResult<SysOrgDetailRespDTO> getDetailByCode(@NotBlank(message = "组织编码为空") @RequestParam("code") String code,
                                                   @RequestParam(value = "withParentType", required = false) String withParentType);

    /**
     * 根据编码获取上级组织信息
     *
     * @param code       组织编码
     * @param parentType 指定上级类型
     * @return 组织信息
     */
    @GetMapping(value = "/getParentByCode")
    ApiResult<SysOrgBasicDTO> getParentByCode(@NotBlank(message = "组织编码为空") @RequestParam("code") String code,
                                              @RequestParam(value = "parentType", required = false) String parentType
    );

    /**
     * 根据编码获取上级组织信息
     *
     * @param codes      组织编码
     * @param parentType 指定上级类型
     * @return 组织信息
     */
    @PostMapping(value = "/getParentsByCode")
    ApiResult<Map<String, SysOrgBasicDTO>> getParentByCode(@NotEmpty(message = "组织编码为空") @RequestBody Set<String> codes,
                                                           @RequestParam(value = "parentType", required = false) String parentType
    );

    /**
     * 查询组织列表
     *
     * @param queryDTO 查询参数
     * @return 组织列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysOrgBasicDTO>> queryList(@RequestBody SysOrgQueryDTO queryDTO);

    /**
     * 分页查询组织
     *
     * @param queryDTO 查询参数
     * @return 组织列表
     */
    @PostMapping(value = "/queryPage")
    ApiResult<PagingVO<SysOrgPageRespDTO>> queryPage(@RequestBody SysOrgPageQueryDTO queryDTO);

    /**
     * 根据ID查询组织编码和名称
     *
     * @param ids 组织ID
     * @return 组织信息
     */
    @PostMapping(value = "/queryCodeAndName")
    ApiResult<List<IdCodeNameParam>> queryCodeAndName(@RequestBody Set<Long> ids);

    /**
     * 根据ID查询组织编码和名称
     *
     * @param codes 组织编码
     * @return 组织信息
     */
    @PostMapping(value = "/queryIdAndName")
    ApiResult<List<IdCodeNameParam>> queryIdAndName(@RequestBody Set<String> codes);
}

==> cloudt-system-api-3.0.15.0.8-20230307.074717-1-sources.jar: com/elitescloud/cloudt/system/provider/org/OrgRpcService.java <==
package com.elitescloud.cloudt.system.provider.org;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.SysOrgBasicDTO;
import com.elitescloud.cloudt.system.dto.req.OrgUpsertDTO;
import com.elitescloud.cloudt.system.param.SysOrgQueryDTO;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.util.List;

/**
 * 组织服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 2/23/2023
 */
@FeignClient(name = Application.NAME, path = OrgRpcService.URI)
@Validated
public interface OrgRpcService {
    String URI = Application.URI_PREFIX + "/org";

    /**
     * 保存组织
     * <p>
     * 如果id不为空，则是修改
     *
     * @param upsertDTO 组织信息
     * @return 组织ID
     */
    @PostMapping(value = "/upsert")
    ApiResult<Long> upsert(@RequestBody @Valid OrgUpsertDTO upsertDTO);

    /**
     * 修改启用状态
     *
     * @param id      组织ID
     * @param enabled 启用状态
     * @return 组织ID
     */
    @PatchMapping(value = "/updateEnabled")
    ApiResult<Long> updateEnabled(@NotNull(message = "组织ID为空") @RequestParam("id") Long id,
                                  @NotNull(message = "启用状态为空") @RequestParam("enabled") Boolean enabled);

    /**
     * 删除组织
     * <p>
     * 如果下面有子组织，则不可直接删除
     *
     * @param id 组织ID
     * @return 组织ID
     */
    @DeleteMapping(value = "/delete")
    ApiResult<Long> delete(@NotNull(message = "组织ID为空") @RequestParam("id") Long id);

    /**
     * 根据ID获取组织信息
     *
     * @param id 组织ID
     * @return 组织信息
     */
    @GetMapping(value = "/getById")
    ApiResult<SysOrgBasicDTO> getById(@NotNull(message = "组织ID为空") @RequestParam("id") Long id);

    /**
     * 根据编码获取组织信息
     *
     * @param code 组织编码
     * @return 组织信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysOrgBasicDTO> getByCode(@NotBlank(message = "组织编码为空") @RequestParam("code") String code);

    /**
     * 查询组织列表
     *
     * @param queryDTO 查询参数
     * @return 组织列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysOrgBasicDTO>> queryList(@RequestBody SysOrgQueryDTO queryDTO);
}
